# Calculating Risk Scores and Updating a Fact Sheet Based on Survey Responses
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#prerequisites)
  * [Step 1: Create a Survey for Risk Assessment](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-1:-create-a-survey-for-risk-assessment)
  * [Step 2: Get the Survey ID](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-2:-get-the-survey-id)
  * [Step 3: Create Custom Fields on Fact Sheets](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-3:-create-custom-fields-on-fact-sheets)
  * [Step 4: Create and Deploy a Function](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-4:-create-and-deploy-a-function)
  * [Step 5: Create a Webhook for Survey Responses](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-5:-create-a-webhook-for-survey-responses)
  * [Step 6: Start a Survey Run](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#step-6:-start-a-survey-run)
  * [Summary](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses#summary)


Learn how to set up an event-triggered automation that calculates the aggregated risk score for a fact sheet based on survey responses and updates this field on a fact sheet.
